@@ -1,4 +1,4 @@
-from .jupyter import *
+from .pyplot import *
 from .generic import *
 from .utils import *
-from ._version import __version__, version_info
\ No newline at end of file
+from ._version import __version__, version_info
